import React from "react";
import PropTypes from "prop-types";
import styling from "@devcake/styling";
import "../init";
import { FormElement } from "../formElement";
import { Label } from "../Label";

styling.link("components.input.disabled", "components.form.disabled");

export type InputProps = FormElement;

export const Input = (props: InputProps) => {
  const { className, disabled, label, nullable, placeholder } = props;
  const value = "value" in props ? props.value : "";
  const onChange = "onChange" in props ? props.onChange : () => null;

  const [innerValue, setInnerValue] = React.useState(value);

  // Update inner value when outer value changes
  React.useEffect(() => setInnerValue(value), [value]);

  let normalizedValue = innerValue;
  if (nullable && normalizedValue === null) normalizedValue = "";

  return (
    <>
      {label && <Label className="mb-1">{label}</Label>}
      <input
        type="text"
        disabled={disabled}
        className={[
          className,
          disabled ? styling.get("components.input.disabled") : "",
          "shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full sm:text-sm border-gray-300 rounded-md"
        ].join(" ")}
        placeholder={placeholder}
        value={normalizedValue}
        onChange={evt => {
          let { value: newValue } = evt.target;
          if (nullable && newValue == "") newValue = null;

          setInnerValue(newValue);
          if (onChange) onChange(newValue);
        }}
      />
    </>
  );
};

Input.propTypes = {
  label: PropTypes.node,
  nullable: PropTypes.bool,
  value: PropTypes.string,
  disabled: PropTypes.bool,
  onChange: PropTypes.func,
  className: PropTypes.string,
  placeholder: PropTypes.string,
};

Input.defaultProps = {
  disabled: false,
  nullable: true,
};
